@@ -22,6 +22,7 @@ from sentry_sdk.integrations import setup_integrations
 from sentry_sdk.utils import ContextVar
 from sentry_sdk.sessions import SessionFlusher
 from sentry_sdk.envelope import Envelope
+from sentry_sdk.profiler import setup_profiler
 from sentry_sdk.tracing_utils import has_tracestate_enabled, reinflate_tracestate
 
 from sentry_sdk._types import MYPY
@@ -130,6 +131,13 @@ class _Client(object):
         finally:
             _client_init_debug.set(old_debug)
 
+        profiles_sample_rate = self.options["_experiments"].get("profiles_sample_rate")
+        if profiles_sample_rate is not None and profiles_sample_rate > 0:
+            try:
+                setup_profiler(self.options)
+            except ValueError as e:
+                logger.debug(str(e))
+
     @property
     def dsn(self):
         # type: () -> Optional[str]
@@ -403,6 +411,7 @@ class _Client(object):
             if is_transaction:
                 if "profile" in event_opt:
                     event_opt["profile"]["transaction_id"] = event_opt["event_id"]
+                    event_opt["profile"]["environment"] = event_opt.get("environment")
                     event_opt["profile"]["version_name"] = event_opt.get("release", "")
                     envelope.add_profile(event_opt.pop("profile"))
                 envelope.add_transaction(event_opt)
